# manageproject - Manage Python / Django projects

[![pytest](https://github.com/jedie/manageproject/actions/workflows/pytest.yml/badge.svg?branch=main)](https://github.com/jedie/manageproject/actions/workflows/pytest.yml)
[![codecov](https://codecov.io/github/jedie/manageproject/branch/main/graph/badge.svg)](https://codecov.io/github/jedie/manageproject)

Mix the idea of Ansible with CookieCutter Templates and Django Migrations to manage and update your Python Packages and Django Projects...

## Links

* https://github.com/cookiecutter/cookiecutter
* Available Cookiecutters template on GitHub: https://github.com/search?q=cookiecutter&type=Repositories
* Packaging Python Projects: https://packaging.python.org/en/latest/tutorials/packaging-projects/
